import React, { PropTypes } from 'react'
import styled from 'styled-components'
import Pane from './Pane'
import Text from './Text'
import Link from './Link'
import Box from './Box'
import SegmentLogo from './SegmentLogo'

const NavigationBarLink = styled((props) => <Link circle paddingX={3} marginX={1} paddingY={1} {...props} />)`
  color: ${props => props.theme.rawColors.blue100};

  &:hover {
    color: white;
    background-color: ${props => props.theme.rawColors.blue800};
  }

  &:active,
  &.active {
    color: white;
    background-color: ${props => props.theme.rawColors.blue500};
  }
`

const NavigationBarTitle = ({ children, ...props }) =>
  <Text is='h1' textStyle='display3' {...props}><strong>{children}</strong></Text>

// paddingTop is somewhat of a hack here, but flex will cause the truncate to fail
const NavigationBarLeftTitle = ({ children, ...props }) =>
  <Box marginLeft truncate paddingTop='7px' paddingLeft borderLeft borderColor='rgba(255,255,255,0.2)'>
    <Text is='span' textStyle='body1' {...props}>{children}</Text>
  </Box>

const NavigationBarLogo = (props) =>
  <SegmentLogo marginTop='-1px' minWidth='106px' width='106px' {...props} />

const NavigationBarPane = (props) =>
  <Pane alignItems='center' dark display='flex' {...props} />

const NavigationBar = ({ logo, left, right, height, children, ...props }) => {
  let child
  if (typeof children === 'string') {
    child = <NavigationBarTitle>{children}</NavigationBarTitle>
  } else {
    child = children
  }

  let leftChild
  if (typeof left === 'string') {
    leftChild = <NavigationBarLeftTitle>{left}</NavigationBarLeftTitle>
  } else {
    leftChild = left
  }

  return (
    <NavigationBarPane height={height} {...props}>
      <Pane width={4} height='100%' padding={3} display='flex'>{logo} {leftChild}</Pane>
      <Pane flexAuto textAlign='center'>{child}</Pane>
      <Pane width={4} textAlign='right' padding={3}>{right}</Pane>
    </NavigationBarPane>
  )
}

NavigationBar.propTypes = {
  logo: PropTypes.node,
  left: PropTypes.node,
  right: PropTypes.node,
  children: PropTypes.oneOfType([
    PropTypes.node,
    PropTypes.string
  ]),
  height: PropTypes.string
}

NavigationBar.defaultProps = {
  logo: <NavigationBarLogo />,
  height: '58px'
}

export {
  NavigationBar,
  NavigationBarLink,
  NavigationBarTitle
}
