import React, { PropTypes } from 'react'
import styled, { css, withTheme } from 'styled-components'
import Box from './Box'
import DoubleTriangle from './DoubleTriangle'

const styles = ({
  theme
}) => css`
  & select {
    border: none;
    appearance: none;
    color: ${props => props.theme.context.white[0].textColor};
    box-shadow: inset 0 0 0 1px ${props => props.theme.context.white[0].borderColor[0]};
    background-color: white;
  }

  & > select:focus,
  & > select:active {
    outline: none;
    box-shadow: inset 0 0 0 1px ${props => props.theme.colors.primary[0]};
  }
`

const SelectWrapperBox = styled(Box)`${styles}`

const SelectIcon = withTheme(({ theme, ...props }) =>
  <DoubleTriangle fill={theme.colors.darkTint[0]} position='absolute' style={{ transform: 'translateY(-50%)', pointerEvents: 'none' }} top='50%' right='12px' />)

const Select = (props) =>
  <SelectWrapperBox position='relative'>
    <SelectIcon />
    <Box {...props} />
  </SelectWrapperBox>

Select.propTypes = {
  ...Box.propTypes
}

Select.defaultProps = {
  is: 'select',
  rounded: true,
  width: '100%',
  paddingX: 4,
  paddingY: 2,
  textStyle: 'body1'
}

Select.displayName = 'Select'

export default Select
