import React, { PropTypes } from 'react'
import Pane from './Pane'
import Text from './Text'
import Link from './Link'
import Box from './Box'
import styled from 'styled-components'

const SubNavigationBarLink = styled((props) =>
  <Link secondary textStyle='body1' paddingBottom marginLeft={3} marginRight={3} {...props} />)`
    &:active,
    &:hover,
    &.active {
      box-shadow: 0 1px ${props => props.theme.rawColors.blue500};
    }
  `

const SubNavigationBarTitle = (props) =>
  <Text is='h2' textStyle='display4' {...props} />

const SubNavigationBarPane = (props) =>
  <Pane display='flex' white borderBottom {...props} />

const SubNavigationBar = ({ left, right, children }) => {

  let leftChild
  if (typeof left === 'string') {
    leftChild = <SubNavigationBarTitle>{left}</SubNavigationBarTitle>
  } else {
    leftChild = left
  }

  return (
    <SubNavigationBarPane>
      <Pane width={3} padding flex='0 0 auto'>{leftChild}</Pane>
      <Pane flexAuto textAlign='center' display='flex' alignItems='flex-end' justifyContent='center'>{children}</Pane>
      <Pane width={3} textAlign='right' flex='0 0 auto'>{right}</Pane>
    </SubNavigationBarPane>
  )
}

SubNavigationBar.propTypes = {
  ...Box.propTypes,
  left: PropTypes.oneOfType([
    PropTypes.node,
    PropTypes.string
  ]),
  right: PropTypes.node
}

export {
  SubNavigationBar,
  SubNavigationBarTitle,
  SubNavigationBarLink
}
